==> zio-aws-amplifybackend_2.13-5.17.127.1-sources.jar: zio/aws/amplifybackend/model/DeleteTokenRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteTokenRequest(appId: __string, sessionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest = {
    import DeleteTokenRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .sessionId(__string.unwrap(sessionId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.DeleteTokenRequest.ReadOnly =
    zio.aws.amplifybackend.model.DeleteTokenRequest.wrap(buildAwsValue())
}
object DeleteTokenRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.DeleteTokenRequest =
      zio.aws.amplifybackend.model.DeleteTokenRequest(appId, sessionId)
    def appId: __string
    def sessionId: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getSessionId: ZIO[Any, Nothing, __string] = ZIO.succeed(sessionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest
  ) extends zio.aws.amplifybackend.model.DeleteTokenRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
    override val sessionId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.sessionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest
  ): zio.aws.amplifybackend.model.DeleteTokenRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifybackend_2.13-5.17.280.1-sources.jar: zio/aws/amplifybackend/model/DeleteTokenRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteTokenRequest(appId: __string, sessionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest = {
    import DeleteTokenRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest
      .builder()
      .appId(appId: java.lang.String)
      .sessionId(sessionId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.DeleteTokenRequest.ReadOnly =
    zio.aws.amplifybackend.model.DeleteTokenRequest.wrap(buildAwsValue())
}
object DeleteTokenRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.DeleteTokenRequest =
      zio.aws.amplifybackend.model.DeleteTokenRequest(appId, sessionId)
    def appId: __string
    def sessionId: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getSessionId: ZIO[Any, Nothing, __string] = ZIO.succeed(sessionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest
  ) extends zio.aws.amplifybackend.model.DeleteTokenRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
    override val sessionId: __string = impl.sessionId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteTokenRequest
  ): zio.aws.amplifybackend.model.DeleteTokenRequest.ReadOnly = new Wrapper(
    impl
  )
}
